Enhanced error handling with contextual information and recovery suggestions
This module provides comprehensive error types with rich context and actionable recovery suggestions to improve developer experience.
Structs
- Error
Context - Error context information
- Error
Migration Helper - Migration utilities for common error patterns
- Trustformers
Error - Core error type with context and recovery suggestions
Enums
Traits
- Result
Ext - Extension trait for adding context to Results
- Result
Standardization - Extension trait for Result types to add standardization
- Standard
Error - Standard error interface that all modules should use
- Timed
Result Ext - Result extension trait for adding error context with timing
Functions
- acceleration_
error - Helper function for hardware acceleration errors
- checkpoint_
error - Helper function for checkpoint loading errors
- compute_
error - Helper function for compute errors
- dimension_
mismatch - Helper function for dimension mismatch errors
- file_
not_ found - Helper function for file not found errors
- hardware_
error - Helper function for hardware errors
- invalid_
config - Helper function for configuration errors
- invalid_
format - Helper function for invalid format errors
- invalid_
input - Helper function for invalid input errors
- memory_
error - Helper function for memory errors
- model_
compatibility_ error - Helper function for model compatibility errors
- model_
not_ found - Helper function for model not found errors
- not_
implemented - Helper function for not implemented errors
- out_
of_ memory - Helper function for OOM errors
- performance_
error - Helper function for performance errors
- quantization_
error - Helper function for quantization errors
- resource_
exhausted - Helper function for resource exhausted errors
- runtime_
error - Helper function for runtime errors
- shape_
mismatch - Helper function for shape mismatch errors
- tensor_
op_ error - Helper function for tensor operation errors
- timed_
error - Helper function for creating errors with timing information
- timeout_
error - Helper function for timeout errors
- unsupported_
operation - Helper function for unsupported operation errors
Type Aliases
- Result
- Result type alias